@@ -40,8 +40,11 @@ def cli():
     args = parser.parse_args()
 
     if args.create:
-        with open(args.filename, "w+") as f:
-            f.write(template)
+        if os.path.exists(args.filename):
+            print("File already exists.")
+        else:
+            with open(args.filename, "w+") as f:
+                f.write(template)
     else:
         os.system(f"g++ {args.filename}")
         os.system(f"./a.out")
